@@ -108,6 +108,13 @@ impl Grid {
             self.set_text(&entity, text);
         }
 
+        if settings.ident.is_none() && settings.alignment.is_none() {
+            return;
+        }
+
+        // todo: might it's worth to be able to modify only ident/alignemt of a cell instead of the whole style
+        // an example when we have a global setting with ident and we only want to modify an alignment of a partical cell
+        // but Style::default() will override global ident...
         let mut s = Style::default();
         if let Some(ident) = settings.ident {
             s.ident = ident;
@@ -119,6 +126,11 @@ impl Grid {
         self.styles.insert(entity, s);
     }
 
+    /// get_cell_content returns content without any style changes
+    pub fn get_cell_content(&mut self, row: usize, column: usize) -> &str {
+        self.cells[row][column].as_str()
+    }
+
     /// Count_rows returns an amount of rows on the grid
     pub fn count_rows(&self) -> usize {
         self.size.0
@@ -352,7 +364,7 @@ impl Settings {
         self
     }
 
-    /// Ident method sets alignment for a cell
+    /// Alignment method sets alignment for a cell
     pub fn alignment(mut self, alignment: Alignment) -> Self {
         self.alignment = Some(alignment);
         self
@@ -527,7 +539,6 @@ impl Alignment {
 
 impl std::fmt::Display for Grid {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        // fixme: calculate it correctly
         let columns_width = self.columns_width();
         let rows = self.build_cells();
 
@@ -618,6 +629,7 @@ fn split_text(text: &str, width: usize, height: usize) -> Vec<Cow<str>> {
     lines
 }
 
+#[cfg(not(feature = "color"))]
 fn string_width(text: &str) -> usize {
     text.lines()
         .map(|line| line.chars().filter(|c| !c.is_control()).count())
@@ -625,6 +637,15 @@ fn string_width(text: &str) -> usize {
         .unwrap_or_else(|| 0)
 }
 
+#[cfg(feature = "color")]
+fn string_width(text: &str) -> usize {
+    console::strip_ansi_codes(text)
+        .lines()
+        .map(|line| line.chars().filter(|c| !c.is_control()).count())
+        .max()
+        .unwrap_or_else(|| 0)
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -705,7 +726,7 @@ mod tests {
             Entity::Global,
             Settings::new().text("asd").ident(1, 1, 1, 1),
         );
-        grid.set(Entity::Column(0), Settings::new());
+        grid.set(Entity::Column(0), Settings::new().ident(0, 0, 0, 0));
         let str = grid.to_string();
         assert_eq!(
             str,
@@ -792,4 +813,13 @@ mod tests {
              +---+---+\n"
         )
     }
+
+    #[cfg(feature = "color")]
+    #[test]
+    fn colored_string_width_test() {
+        use colored::Colorize;
+        assert_eq!(string_width(&"hello world".red().to_string()), 11);
+        assert_eq!(string_width(&"hello\nworld".blue().to_string()), 5);
+        assert_eq!(string_width("\u{1b}[34m0\u{1b}[0m"), 1);
+    }
 }
